==> classiq_interface-0.1.6.tar.gz: classiq_interface-0.1.6/classiq_interface/generator/hardware_efficient_ansatz.py <==
from typing import Type, Tuple, List
from enum import Enum
import pydantic

from classiq_interface.generator import function_params


AnsatzOutputs = function_params.DefaultOutputNames
AnsatzInputs = function_params.DefaultInputNames


class HardwareEfficientAnsatz(function_params.FunctionParams):
    num_qubits: pydantic.conint(ge=1) = pydantic.Field(
        description="Number of qubits in the ansatz"
    )
    connectivity_map: List[List[pydantic.NonNegativeInt]] = pydantic.Field(
        description="Hardware's connectivity map, in the form [ [x0, x1], [x1, x2],...]"
    )
    depth: pydantic.conint(ge=1) = pydantic.Field(
        default=1, description="Number of layers in the Ansatz"
    )

    @pydantic.validator("connectivity_map")
    def validate_connectivity_map(cls, connectivity_map, values):
        num_qubits = values.get("num_qubits")
        if num_qubits is None:
            return
        for connection in connectivity_map:
            if len(connection) != 2:
                raise ValueError(
                    f"Connectivity {connection} is invalid, must connect exactly 2 qubits"
                )
            for index in connection:
                if index >= num_qubits:
                    raise ValueError(
                        f"Provided index {index} is bigger than num_qubits-1"
                    )
        return connectivity_map

    _input_names: Type[Enum] = pydantic.PrivateAttr(default=AnsatzInputs)
    _output_names: Type[Enum] = pydantic.PrivateAttr(default=AnsatzOutputs)

==> classiq_interface-0.1.7.tar.gz: classiq_interface-0.1.7/classiq_interface/generator/hardware_efficient_ansatz.py <==
from typing import Type, Tuple, List
from enum import Enum
import pydantic

from classiq_interface.generator import function_params


class AnsatzInputs(Enum):
    IN = "IN"


AnsatzOutputs = function_params.DefaultOutputEnum


class HardwareEfficientAnsatz(function_params.FunctionParams):
    num_qubits: pydantic.conint(ge=1) = pydantic.Field(
        description="Number of qubits in the ansatz"
    )
    connectivity_map: List[List[pydantic.NonNegativeInt]] = pydantic.Field(
        description="Hardware's connectivity map, in the form [ [x0, x1], [x1, x2],...]"
    )
    depth: pydantic.conint(ge=1) = pydantic.Field(
        default=1, description="Number of layers in the Ansatz"
    )

    _input_enum: Type[Enum] = pydantic.PrivateAttr(default=AnsatzInputs)
    _output_enum: Type[Enum] = pydantic.PrivateAttr(default=AnsatzOutputs)

    @pydantic.validator("connectivity_map")
    def validate_connectivity_map(cls, connectivity_map, values):
        num_qubits = values.get("num_qubits")
        if num_qubits is None:
            return
        for connection in connectivity_map:
            if len(connection) != 2:
                raise ValueError(
                    f"Connectivity {connection} is invalid, must connect exactly 2 qubits"
                )
            for index in connection:
                if index >= num_qubits:
                    raise ValueError(
                        f"Provided index {index} is bigger than num_qubits-1"
                    )
        return connectivity_map
